
/*  @(#)option.h 1.14 95/08/25
 *
 *  Contains definitions for class "Option".
 *
 *  Copyright (c) Steve Holden and Rich Burridge.
 *                All rights reserved.
 *
 *  Permission is given to distribute these sources, as long as the
 *  copyright messages are not removed, and no monies are exchanged.
 *
 *  No responsibility is taken for any errors or inaccuracies inherent
 *  either to the comments or the code of this program, but if
 *  reported to me then an attempt will be made to fix them.
 */

#include <X11/Xlib.h>
#include <X11/Xresource.h>

#define  FCLOSE   (void) fclose
#define  FPRINTF  (void) fprintf
#define  FPUTS    (void) fputs
#define  FREE     (void) free
#define  PCLOSE   (void) pclose
#define  PUTC     (void) putc
#define  SSCANF   (void) sscanf
#define  SPRINTF  (void) sprintf
#define  STRCAT   (void) strcat
#define  STRCPY   (void) strcpy
#define  STRNCPY  (void) strncpy
#define  UNGETC   (void) ungetc

#define  DEFCOLUMNS    1    /* Number of columns per page. */
#define  DEFCOPIES     1    /* Number of copies of each file. */
#define  DEFMARGIN     8    /* Default margin size (in points). */
#define  LINELENGTH    80   /* Number of characters per line. */
#define  MAXCOPIES     500  /* Maximum number of copies to print. */
#define  MAXHDRS       64   /* Maximum number of -addhdr or -remhdr options. */
#define  MAXLINE       256  /* Maximum string length. */
#define  MAXMARGIN     500  /* Maximum margin size (in points). */
#define  MAXNAMES      512  /* Maximum number of files from command line. */
#define  MAXRESOURCES  40   /* Maximum number of mp X resources. */
#define  NAMEFIELDS    3    /* Default no. of "words" from passwd gecos. */
#define  NAMELENGTH    40   /* Maximum allowable real user name. */
#define  PAGELENGTH    72   /* Number of lines per page. */
#define  TABSIZE       8    /* Number of spaces in a tab char. */

#define  ARG_EQUAL(s, n)      (!argcmp(argv[i], s, n))
#define  CASE_EQUAL(a, b)     (!strcasecmp(a, b))
#define  EQUAL(a, b)          (!strcmp(a, b))
#define  OLD_ARG_EQ(s)        (!strcmp(argv[i], s))

#ifndef  MAXPATHLEN
#define  MAXPATHLEN   1024
#endif /*MAXPATHLEN*/

#ifndef  PROLOGUE                             /* PostScript prologue file. */
#define  PROLOGUE          "/usr/local/lib/mp"
#endif /*PROLOGUE*/

#define  PRO_FILOFAX       "mp.pro.ff.ps"
#define  PRO_FILOFAXP      "mp.pro.ffp.ps"
#define  PRO_FRANKLIN      "mp.pro.fp.ps"
#define  PRO_LANDSCAPE     "mp.pro.l.ps"
#define  PRO_NORMAL        "mp.pro.ps"
#define  PRO_OTHER         "other"
#define  PRO_PRO_PLAN      "mp.pro.pp.ps"
#define  PRO_TIME_MANAGER  "mp.pro.tm.ps"
#define  PRO_TS_INTL       "mp.pro.tsi.ps"
#define  PRO_TS_PARTNER    "mp.pro.tsp.ps"

enum header_type { H_ADD, H_REMOVE } ;

enum margin_type { M_BOTTOM,   M_LEFT,      M_RIGHT,     M_TOP } ;

enum opt_type   { O_ADDHDRN,   O_ALIAS,     O_ALLHDRS,   O_APPNAME,
                  O_ARTICLE,   O_BANNERS,   O_BSDPRINT,  O_BURSTPAGE,
                  O_CONTENT,
                  O_COPIES,    O_DIGEST,    O_DUPLEX,    O_ELM,
                  O_FLIP,      O_FOLDER,    O_FORCEPAGE, O_GSUBJECT,
                  O_LANDSCAPE, O_LLEN,      O_MODTIME,   O_NAMEF,
                  O_NAMELEN,   O_NUMBER,    O_NUMCOLS,   O_NUMNAMES,
#ifdef MIME_SUPPORT
                  O_PAGIN,
#endif /*MIME_SUPPORT*/
                  O_PLEN,      O_PR_NAME,   O_PR_ORIG,   O_PRINT_PS,
                  O_REMHDRN,   O_TABSIZE,   O_TEXTDOC,   O_TOPRINT,
                  O_TUMBLE,    O_WRAPW } ;

enum paper_type { P_NONE, P_A4, P_US } ;

enum res_type   { R_FTYPE,    R_OTYPE,    R_ORGANISER, R_PSIZE,
                  R_HDRPAGE,  R_MAIL_FDR, R_MAIL_DIG,  R_SUBJECT,
                  R_LLENGTH,  R_PLENGTH,  R_COPIES,    R_PNAME,
                  R_DSIDED,   R_ADDHDRS,  R_REMHDRS,   R_PROLOG,
                  R_ALIAS,    R_NCOLUMNS, R_TABSIZE,   R_NAMEC,
                  R_NAMEW,    R_WRAP,     R_FLIP,      R_FORCEPAGE,
                  R_ELM,      R_NUMBER,   R_FROM,      R_CONTENT,
                  R_MOD,      R_TUMBLE,   R_ALLHDRS,   R_BSDPRINT,
                  R_BMARGIN,  R_LMARGIN,  R_RMARGIN,   R_TMARGIN,
#ifdef MIME_SUPPORT
                  R_BOUNDARY, R_TYPESIZE, R_PAGINATE,
#endif /*MIME_SUPPORT*/
                  R_BANNERS } ;

extern char *prologue ;               /* Name of PostScript prologue file. */
extern char proname[MAXPATHLEN] ;     /* Full pathname of the prologue file. */
extern char *ptype ;                  /* Prologue type. */

extern enum paper_type paper_size ;   /* Paper size - default None. */

#ifdef MIME_SUPPORT
extern char *boundary ;
extern int typesize ;
extern int paginate ;
#endif /*MIME_SUPPORT*/

extern char *get_filename          (int) ;
extern char *get_hdr               (enum header_type, int) ;
extern char *str_opt_val           (enum opt_type) ;

extern int  get_margin             (enum margin_type) ;
extern int  int_opt_val            (enum opt_type) ;
extern int  is_opt_given           (enum opt_type) ;

extern void adjust_paper_size      (void) ;
extern void free_hdr               (enum header_type, int) ;
extern void get_appname            (int, char **) ;
extern void get_hdr_arg            (char *, enum header_type, int *) ;
extern void get_options            (int, char **) ;
extern void Option                 (void) ;
extern void set_int_opt_val        (enum opt_type, int) ;
extern void set_margin             (enum margin_type, int) ;
extern void set_str_opt_val        (enum opt_type, char *) ;
extern void read_resources         (void) ;
extern void write_resources        (void) ;
