
/*  @(#)base.c 1.6 95/08/25
 *
 *  Various routines associated with the input popup.
 *
 *  Copyright (c) Rich Burridge.    All rights reserved.
 *
 *  Permission is given to distribute these sources, as long as the
 *  copyright messages are not removed, and no monies are exchanged.
 *
 *  No responsibility is taken for any errors or inaccuracies inherent
 *  either to the comments or the code of this program, but if
 *  reported to me then an attempt will be made to fix them.
 */

#include "mptool.h"
#include "patchlevel.h"
#include "mptool.xbm"
#include "mptool.xpm"
#include "printing.xbm"
#include "printing.xpm"
#include <Xm/AtomMgr.h>
#include <Xm/FileSB.h>
#include <Xm/Text.h>

char *filenames ;         /* List of file(s) to print. */
Atom COMPOUND_TEXT ;
Display *dpy ;
int depth ;               /* Depth of the screen in pixels. */
int screen ;
Window root ;
Widget *warr ;

static Pixmap nicon ;            /* Normal icon image. */
static Pixmap picon ;            /* Printing icon image. */
static Widget fpopup ;           /* File Selection dialog popup. */
static Widget *fwarr ;


void
Base(void)
{
  filenames = NULL ;     /* List of file(s) to print. */
  fpopup    = NULL ;     /* No file selection popup window initially. */
  fwarr     = NULL ;
  warr      = NULL ;
}


void
do_copies_dec(void)
{
  int copies = int_opt_val(O_COPIES) ;

  if (copies > 1) set_int_opt_val(O_COPIES, copies - 1) ;
  set_int_value(F_MAIN, WI_COPIES, int_opt_val(O_COPIES)) ;
}


void
do_copies_inc(void)
{
  int copies = int_opt_val(O_COPIES) ;

  if (copies < MAXCOPIES) set_int_opt_val(O_COPIES, copies + 1) ;
  set_int_value(F_MAIN, WI_COPIES, int_opt_val(O_COPIES)) ;
}


void
do_exit_mptool(void)
{
  exit(0) ;
}


void
do_file_apply(void)
{
  char all[BUFFERSIZE], *previous, *newfile ;
  Widget textw ;

  previous = get_str_value(F_MAIN, WI_FILENAME) ;
  textw    = XmFileSelectionBoxGetChild(fwarr[WI_FILE_FRAME], XmDIALOG_TEXT) ;
  newfile  = XmTextGetString(textw) ;
  all[0] = '\0' ;
  if (previous && *previous) STRCAT(all, previous) ;
  if (newfile  && *newfile)
    {
      if (previous && *previous) STRCAT(all, " ") ;
      STRCAT(all, newfile) ;
    }
  set_str_value(F_MAIN, WI_FILENAME, all) ;
}


void
do_file_dismiss(void)
{
  XtUnmapWidget(fpopup) ;
  XtUnmanageChild(fpopup) ;
}


void
do_print_files(void)
{
  char *names = get_str_value(F_MAIN, WI_FILENAME) ;

  do_print_cmd(names) ;
}


void
do_reset_options(void)
{
       if (int_opt_val(O_ARTICLE))  set_excl_value(F_MAIN, WI_FILE_TYPE_NEWS) ;
  else if (int_opt_val(O_PRINT_PS)) set_excl_value(F_MAIN, WI_FILE_TYPE_POST) ;
  else if (int_opt_val(O_TEXTDOC))  set_excl_value(F_MAIN, WI_FILE_TYPE_TEXT) ;
 
  set_excl_value(F_MAIN, WI_OUTPUT_PORT) ;
       if (int_opt_val(O_LANDSCAPE))
    set_excl_value(F_MAIN, WI_OUTPUT_LAND) ;
  else if (!EQUAL(ptype, PRO_NORMAL))
    set_excl_value(F_MAIN, WI_OUTPUT_PERORG) ;
 
  set_excl_value(F_MAIN, WI_ORG_TYPE_FF) ;   /* Default to Filofax. */

       if (EQUAL(ptype, PRO_FRANKLIN))
    set_excl_value(F_MAIN, WI_ORG_TYPE_FP) ;
  else if (EQUAL(ptype, PRO_PRO_PLAN))
    set_excl_value(F_MAIN, WI_ORG_TYPE_PP) ;
  else if (EQUAL(ptype, PRO_TIME_MANAGER))
    set_excl_value(F_MAIN, WI_ORG_TYPE_TM) ;
  else if (EQUAL(ptype, PRO_TS_INTL))
    set_excl_value(F_MAIN, WI_ORG_TYPE_TSI) ;
  else if (EQUAL(ptype, PRO_TS_PARTNER))
    set_excl_value(F_MAIN, WI_ORG_TYPE_TSP) ;

       if (paper_size == P_A4) set_excl_value(F_MAIN, WI_PAPER_SIZE_A4) ;
  else if (paper_size == P_US) set_excl_value(F_MAIN, WI_PAPER_SIZE_US) ;

  set_str_value(F_MAIN, WI_SUBJECT,  str_opt_val(O_GSUBJECT)) ;
  set_int_value(F_MAIN, WI_COPIES,   int_opt_val(O_COPIES)) ;
  set_str_value(F_MAIN, WI_FILENAME, filenames) ;

  if (int_opt_val(O_DUPLEX)) set_excl_value(F_MAIN, WI_NO_SIDES_DOUBLE) ;
  else                       set_excl_value(F_MAIN, WI_NO_SIDES_SINGLE) ;
}


void
do_save_defaults(void)
{
  get_main_vals() ;
  write_resources() ;
}


void
do_show_base(void)
{
  char title[MAXLINE] ;

  (void) tu_main_frame_widget("mptool", NULL, &warr) ;
  COMPOUND_TEXT = XmInternAtom(XtDisplay(warr[WI_MAIN_FRAME]),
                               "COMPOUND_TEXT", False) ;
#ifndef NO_DND
  init_dnd(warr[WI_MAIN_FORM]) ;
#endif // NO_DND

  add_help(warr[WI_MAIN_FORM],          wi_main_frame_help) ;
  add_help(warr[WI_FILENAME_LABEL],     wi_filename_help) ;
  add_help(warr[WI_FILENAME],           wi_filename_help) ;
  add_help(warr[WI_HEADERS],            wi_headers_help) ;
  add_help(warr[WI_FILE_TYPE_LABEL],    wi_file_type_help) ;
  add_help(warr[WI_FILE_TYPE],          wi_file_type_help) ;
  add_help(warr[WI_ORGANISER],          wi_org_type_help) ;
  add_help(warr[WI_ORGANISER_MENU],     wi_org_type_help) ;
  add_help(warr[WI_OUT_LABEL],          wi_output_help) ;
  add_help(warr[WI_OUT_TYPE],           wi_output_help) ;
  add_help(warr[WI_PAPER_SIZE_LABEL],   wi_paper_size_help) ;
  add_help(warr[WI_PAPER_SIZE],         wi_paper_size_help) ;
  add_help(warr[WI_SUBJECT_LABEL],      wi_subject_help) ;
  add_help(warr[WI_SUBJECT],            wi_subject_help) ;
  add_help(warr[WI_COPIES_LABEL],       wi_copies_help) ;
  add_help(warr[WI_COPIES],             wi_copies_help) ;
  add_help(warr[WI_NO_SIDES_LABEL],     wi_no_sides_help) ;
  add_help(warr[WI_NO_SIDES],           wi_no_sides_help) ;
  add_help(warr[WI_PRINT],              wi_print_help) ;
  add_help(warr[WI_RESET],              wi_reset_help) ;
  add_help(warr[WI_SAVE],               wi_props_defs_help) ;
  add_help(warr[WI_MENU_BAR],           wi_menu_bar_help) ;
  add_help(warr[WI_FILE_MB],            wi_menu_bar_help) ;
  add_help(warr[WI_FILE_MENU],          wi_menu_bar_help) ;
  add_help(warr[WI_EXIT],               wi_exit_help) ;
  add_help(warr[WI_OPTIONS],            wi_menu_bar_help) ;
  add_help(warr[WI_OPTIONS_MENU],       wi_menu_bar_help) ;
  add_help(warr[WI_HEADERS],            wi_header_frame_help) ;
  add_help(warr[WI_INPUT],              wi_input_frame_help) ;
  add_help(warr[WI_OUTPUT],             wi_output_frame_help) ;
  add_help(warr[WI_PRINTING],           wi_props_frame_help) ;
  add_help(warr[WI_SAVE],               wi_props_defs_help) ;
  add_help(warr[WI_USERNAME],           wi_un_form_help) ;
  add_help(warr[WI_HELP],               wi_help_help) ;
  add_help(warr[WI_HELP_MENU],          wi_menu_bar_help) ;
  add_help(warr[WI_GENERAL_HELP],       wi_main_frame_help) ;
  add_help(warr[WI_HEADERS_HELP],       wi_header_frame_help) ;
  add_help(warr[WI_INPUT_HELP],         wi_input_frame_help) ;
  add_help(warr[WI_OUTPUT_HELP],        wi_output_frame_help) ;
  add_help(warr[WI_PRINTING_HELP],      wi_props_frame_help) ;
  add_help(warr[WI_SAVE_HELP],          wi_props_defs_help) ;
  add_help(warr[WI_USERNAME_HELP],      wi_un_form_help) ;

  dpy    = tu_disp_get_dpy(NULL) ;
  screen = DefaultScreen(dpy) ;
  root   = RootWindow(dpy, screen) ;
  depth  = DefaultDepth(dpy, screen) ;
  if (DisplayCells(dpy, screen) > 2)
    {
      nicon = create_mp_pixmap(concat_strs(mptool_xpm_bits)) ;
      picon = create_mp_pixmap(concat_strs(printing_xpm_bits)) ;
    }
  else
    { 
      nicon = XCreatePixmapFromBitmapData(dpy, RootWindow(dpy, screen),
                      (char *) mptool_xbm_bits,
                      mptool_xbm_width, mptool_xbm_height, 1, 0, 1) ;
      picon = XCreatePixmapFromBitmapData(dpy, RootWindow(dpy, screen),
                      (char *) printing_xbm_bits,
                      printing_xbm_width, printing_xbm_height, 1, 0, 1) ;
    }
  SPRINTF(title, mptool_strs[(int) S_USAGE], PATCHLEVEL) ;
  XtVaSetValues(warr[WI_MAIN_FRAME],
                XmNiconName,   "mptool",
                XmNiconPixmap, nicon,
                XmNtitle,      title,
                0) ;
}


void
do_show_file(void)
{
  if (!fpopup)
    {
      fpopup = tu_file_frame_widget("filename", warr[WI_MAIN_FRAME], &fwarr) ;
      XtRealizeWidget(fpopup) ;
      XSync(dpy, 0) ;

/*  XmCreateFileSelectionDialog returns the widget-id of its child which is a
 *  FileSelectionBox.  We need the parent shell here (= DialogShell).
 *  This avoids the message "must be a vendor shell".
 */
      add_delete_callback(XtParent(fpopup)) ;
    }
  show_popup(fpopup) ;
}


void
get_main_vals(void)
{
  set_int_opt_val(O_ARTICLE,   get_bool_value(F_MAIN, WI_FILE_TYPE_NEWS)) ;
  set_int_opt_val(O_PRINT_PS,  get_bool_value(F_MAIN, WI_FILE_TYPE_POST)) ;
  set_int_opt_val(O_TEXTDOC,   get_bool_value(F_MAIN, WI_FILE_TYPE_TEXT)) ;
  set_str_opt_val(O_GSUBJECT,  get_str_value(F_MAIN,  WI_SUBJECT)) ;
  set_int_opt_val(O_COPIES,    get_int_value(F_MAIN,  WI_COPIES)) ;
  set_int_opt_val(O_DUPLEX,    get_bool_value(F_MAIN, WI_NO_SIDES_DOUBLE)) ;
  set_int_opt_val(O_LANDSCAPE, get_bool_value(F_MAIN, WI_OUTPUT_LAND)) ;

  if (int_opt_val(O_LANDSCAPE)) ptype = PRO_LANDSCAPE ;
  else                          ptype = PRO_NORMAL ;

  if (get_bool_value(F_MAIN, WI_OUTPUT_PERORG))
    {
      if (get_bool_value(F_MAIN, WI_ORG_TYPE_FF)) ptype = PRO_FILOFAX ;
      if (get_bool_value(F_MAIN, WI_ORG_TYPE_FP)) ptype = PRO_FRANKLIN ;
      if (get_bool_value(F_MAIN, WI_ORG_TYPE_PP)) ptype = PRO_PRO_PLAN ;
      if (get_bool_value(F_MAIN, WI_ORG_TYPE_TM)) ptype = PRO_TIME_MANAGER ;

      if (get_bool_value(F_MAIN, WI_ORG_TYPE_TSI)) ptype = PRO_TS_INTL ;
      if (get_bool_value(F_MAIN, WI_ORG_TYPE_TSP)) ptype = PRO_TS_PARTNER ;
    }

       if (get_bool_value(F_MAIN, WI_PAPER_SIZE_A4)) paper_size = P_A4 ;
  else if (get_bool_value(F_MAIN, WI_PAPER_SIZE_US)) paper_size = P_US ;
  else                                               paper_size = P_NONE ;
}


void
set_icon(enum icon_type itype)
{
  Pixmap icon = (itype == I_NORMAL) ? nicon : picon ;

  XtVaSetValues(warr[WI_MAIN_FRAME], XmNiconPixmap, icon, 0) ;
}
